@@ -3,6 +3,6 @@ from tier import Tier
 
 class Oozie(Tier):
     tier = "oozie-*"
-    modules = ["hive_scripts", "hadoop", "hustler", "hive", "sqoop", "oozie", "pig", "tapp2"]
+    modules = ["hive_scripts", "hadoop", "hustler", "hive", "sqoop", "pig", "tapp2"]
     def __init__(self, subparser):
         super(Oozie, self).__init__(subparser)
