@@ -2,7 +2,7 @@ from tier import Tier
 
 
 class OozieSlave(Tier):
+    tier = "oozie-slave"
+    modules = ["hive_scripts", "hadoop", "hustler", "hive", "sqoop", "pig", "tapp2"]
     def __init__(self, subparser):
-        self.tier = "oozie-slave"
-        self.modules = ["hive_scripts", "hadoop", "hustler", "hive", "sqoop", "oozie", "pig", "tapp2"]
         super(OozieSlave, self).__init__(subparser)
