@@ -17,7 +17,7 @@ class Scheduler(Tier):
     tier = "scheduler"
     ami_id = "ami-0598906c"
     region = "us-east-1"
-    instance_type = "m1.large"
+    instance_type = "m3.medium"
     run_list = '{"run_list":["recipe[webslave::deploy_scheduler]"],"qubole_tier":"scheduler"}'
     modules = ["scheduler"]
 
@@ -33,7 +33,7 @@ class Scheduler(Tier):
         create.add_argument("-r", "--region", help="Region where the tier will be located",
                             default=self.region, dest="region")
         create.add_argument("-i", "--instance-type", help="Instance Type of the machine",
-                            choices=["t1.micro", "m1.large", "m1.xlarge"], dest="instance_type",
+                            choices=["m3.medium", "m3.large"], dest="instance_type",
                             default=self.instance_type)
         create.add_argument("-t", "--tunnel", dest="tunnel",
                             action="store_true", help="Use a tunnel through a web node")
