@@ -36,7 +36,7 @@ try_lock() {
   echo "Obtained DbLock for deploy"
 }
 
-legal_modules="hive_scripts hadoop hustler hive sqoop oozie pig tapp2"
+legal_modules="hive_scripts hadoop hustler hive sqoop pig tapp2"
 validate_module() {
     module=$1
     found=false
